@@ -55,56 +55,56 @@
 <context>
     <name>CharTableSql</name>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="73"/>
+        <location filename="../sql/chartablesql.cpp" line="165"/>
         <source>Characters</source>
         <translation>Schriftzeichen</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="74"/>
+        <location filename="../sql/chartablesql.cpp" line="166"/>
         <source>Target Errors</source>
         <translation>Soll-Fehler</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="75"/>
+        <location filename="../sql/chartablesql.cpp" line="167"/>
         <source>Actual Errors</source>
         <translation>Ist-Fehler</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="76"/>
+        <location filename="../sql/chartablesql.cpp" line="168"/>
         <source>Frequency</source>
         <translation>Vorkommen</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="77"/>
+        <location filename="../sql/chartablesql.cpp" line="169"/>
         <source>Error Rate</source>
         <translation>Fehlerquote</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="80"/>
+        <location filename="../sql/chartablesql.cpp" line="172"/>
         <source>This column shows all of the
 characters typed</source>
         <translation>Diese Spalte zeigt alle bislang
 eingegebenen Schriftzeichen</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="84"/>
+        <location filename="../sql/chartablesql.cpp" line="176"/>
         <source>The character was supposed to be typed, but wasn&apos;t</source>
         <translation>Das Zeichen sollte getippt werden, wurde es aber nicht</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="87"/>
+        <location filename="../sql/chartablesql.cpp" line="179"/>
         <source>Character was mistyped</source>
         <translation>Charakter wurde falsch getippt</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="89"/>
+        <location filename="../sql/chartablesql.cpp" line="181"/>
         <source>This column indicates the total frequency of each
 character shown</source>
         <translation>Diese Spalte gibt an, wie oft das Schriftzeichen
-ingesamt diktiert wurde</translation>
+insgesamt diktiert wurde</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="93"/>
+        <location filename="../sql/chartablesql.cpp" line="185"/>
         <source>The error rate shows which characters give
 you the most problems. The error rate is
 calculated from the value &quot;Target Error&quot;
@@ -115,12 +115,12 @@ wird auf der Basis von den werten &quot;Ziel-Fehler&quot;
 und &quot;Frequenz&quot; berechnet.</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="117"/>
+        <location filename="../sql/chartablesql.cpp" line="90"/>
         <source>Reset characters</source>
         <translation>Schriftzeichen zurücksetzen</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="191"/>
+        <location filename="../sql/chartablesql.cpp" line="195"/>
         <source>Recorded error rates affect the intelligence feature and the selection of the text to be dictated. If the error rate for a certain character is excessively high it might be useful to reset the list.
 
 All recorded characters will now be deleted.
@@ -268,7 +268,7 @@ Zeit anstandslos lief, ist voraussichtlich die Datenbank beschädigt worden
 (z.B. durch einen Absturz des Computers). Um zu überprüfen, ob die Datenbank
 beschädigt wurde, können Sie die Datenbank-Datei &quot;%1&quot; testweise einmal
 umbenennen und die Software dann neu starten (es sollte dann
-auomatisch eine neue, leere Datenbank angelegt werden).
+automatisch eine neue, leere Datenbank angelegt werden).
 
 Wenn dieses Problem gleich nach dem ersten Start der Software auftrat, fehlen
 voraussichtlich die Schreibrechte auf die Datenbank-Datei.
@@ -299,7 +299,7 @@ Datenbank beschädigt worden (z.B. durch einen Absturz des
 Computers).
 Um zu überprüfen, ob die Datenbank beschädigt wurde, können
 Sie die Datenbank-Datei &quot;%1&quot; testweise einmal umbenennen und die
-Software dann neu starten (es sollte dann auomatisch eine
+Software dann neu starten (es sollte dann automatisch eine
 neue, leere Datenbank angelegt werden).
 
 Wenn dieses Problem gleich nach dem ersten Start der Software
@@ -331,7 +331,7 @@ Datenbank beschädigt worden (z.B. durch einen Absturz des
 Computers).
 Um zu überprüfen, ob die Datenbank beschädigt wurde, können
 Sie die Datenbank-Datei &quot;%1&quot; testweise einmal umbenennen und die
-Software dann neu starten (es sollte dann auomatisch eine
+Software dann neu starten (es sollte dann automatisch eine
 neue, leere Datenbank angelegt werden).
 
 Wenn dieses Problem gleich nach dem ersten Start der Software
@@ -849,7 +849,7 @@ nach mindestens %1 Schriftzeichen.</translation>
     </message>
     <message>
         <location filename="../widget/lessondialog.cpp" line="117"/>
-        <source>&lt;u&gt;Explanation:&lt;/u&gt;&lt;br&gt;&amp;nbsp;&lt;br&gt;Every line (separated by Enter key) is equivalent to a unit of the lesson. There are two types of lesson dictation:&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Sentence Lesson&lt;/b&gt; - every line (sentence) will be dictated exactly how it was entered here with a line break at the end.&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Word Lesson&lt;/b&gt; - the lines will be separated by blanks and a line break passes auomatically after at least %1 characters.</source>
+        <source>&lt;u&gt;Explanation:&lt;/u&gt;&lt;br&gt;&amp;nbsp;&lt;br&gt;Every line (separated by Enter key) is equivalent to a unit of the lesson. There are two types of lesson dictation:&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Sentence Lesson&lt;/b&gt; - every line (sentence) will be dictated exactly how it was entered here with a line break at the end.&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Word Lesson&lt;/b&gt; - the lines will be separated by blanks and a line break passes automatically after at least %1 characters.</source>
         <translation>&lt;u&gt;Erläuterung&lt;/u&gt;&lt;br&gt;&amp;nbsp;&lt;br&gt;Jede Zeile (Zeilenumbruch am Ende) entspricht einer Einheit für das Diktat. Das Diktat kann auf zwei Arten geführt werden:&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Satzdiktat&lt;/b&gt; - die einzelnen Zeilen (Sätze) werden wie hier eingegeben mit einem Zeilenumbruch am Ende diktiert.&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Wortdiktat&lt;/b&gt; - die einzelnen Zeilen (Worte) werden mit Leerzeichen getrennt diktiert, ein Zeilenumbruch erfolgt automatisch nach mindestens %1 diktierten Schriftzeichen.</translation>
     </message>
     <message>
@@ -1132,101 +1132,101 @@ nach mindestens %1 Schriftzeichen.</translation>
 <context>
     <name>LessonTableSql</name>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="126"/>
+        <location filename="../sql/lessontablesql.cpp" line="122"/>
         <source>Show: </source>
         <translation>Zeige: </translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="128"/>
+        <location filename="../sql/lessontablesql.cpp" line="124"/>
         <source>All Lessons</source>
         <translation>Alle Lektionen</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="129"/>
+        <location filename="../sql/lessontablesql.cpp" line="125"/>
         <source>Training Lessons</source>
         <translation>Übungslektionen</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="130"/>
+        <location filename="../sql/lessontablesql.cpp" line="126"/>
         <source>Open Lessons</source>
         <translation>Freie Lektionen</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="131"/>
+        <location filename="../sql/lessontablesql.cpp" line="127"/>
         <source>Own Lessons</source>
         <translation>Eigene Lektionen</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="266"/>
+        <location filename="../sql/lessontablesql.cpp" line="255"/>
         <source>Lesson</source>
         <translation>Lektion</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="267"/>
+        <location filename="../sql/lessontablesql.cpp" line="256"/>
         <source>Time</source>
         <translation>Zeitpunkt</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="268"/>
+        <location filename="../sql/lessontablesql.cpp" line="257"/>
         <source>Duration</source>
         <translation>Dauer</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="269"/>
+        <location filename="../sql/lessontablesql.cpp" line="258"/>
         <source>Characters</source>
         <translation>Zeichen</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="270"/>
+        <location filename="../sql/lessontablesql.cpp" line="259"/>
         <source>Errors</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="271"/>
+        <location filename="../sql/lessontablesql.cpp" line="260"/>
         <source>Rate</source>
         <translation>Quote</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="272"/>
+        <location filename="../sql/lessontablesql.cpp" line="261"/>
         <source>Cpm</source>
         <translation>A/min</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="273"/>
+        <location filename="../sql/lessontablesql.cpp" line="262"/>
         <source>Score</source>
         <translation>Bewertung</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="276"/>
+        <location filename="../sql/lessontablesql.cpp" line="265"/>
         <source>This column shows the names
 of completed lessons</source>
         <translation>Diese Spalte zeigt die Namen
 der absolvierten Lektionen</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="280"/>
+        <location filename="../sql/lessontablesql.cpp" line="269"/>
         <source>Start time of the lesson</source>
         <translation>Startzeitpunkt der Lektion</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="282"/>
+        <location filename="../sql/lessontablesql.cpp" line="271"/>
         <source>Total duration of the lesson</source>
         <translation>Dauer der Lektion insgesamt</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="283"/>
+        <location filename="../sql/lessontablesql.cpp" line="272"/>
         <source>Number of characters dictated</source>
         <translation>Anzahl der Schriftzeichen, die
-ingesamt diktiert wurden</translation>
+insgesamt diktiert wurden</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="286"/>
+        <location filename="../sql/lessontablesql.cpp" line="275"/>
         <source>Number of typing errors</source>
         <translation>Anzahl der Tippfehler, die in
 der Lektion gemacht wurden</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="288"/>
+        <location filename="../sql/lessontablesql.cpp" line="277"/>
         <source>The error rate is calculated as follows:
 Errors / Characters
 The lower the error rate the better!</source>
@@ -1235,14 +1235,14 @@ Diktatlänge (Tippfehler / Zeichen)
 Umso geringer die Fehlerquote, desto besser!</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="293"/>
+        <location filename="../sql/lessontablesql.cpp" line="282"/>
         <source>&quot;Cpm&quot; indicates how many characters per minute
 were entered on average</source>
         <translation>&quot;A/min&quot; besagt, wie viele Schriftzeichen (Anschläge)
 durchschnittlich pro Minute eingegeben wurden</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="297"/>
+        <location filename="../sql/lessontablesql.cpp" line="286"/>
         <source>The score is calculated as follows:
 ((Characters - (20 x Errors)) / Duration in minutes) x 0.4
 
