@@ -55,56 +55,56 @@
 <context>
     <name>CharTableSql</name>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="73"/>
+        <location filename="../sql/chartablesql.cpp" line="165"/>
         <source>Characters</source>
         <translation>Characters</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="74"/>
+        <location filename="../sql/chartablesql.cpp" line="166"/>
         <source>Target Errors</source>
         <translation>Target Errors</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="75"/>
+        <location filename="../sql/chartablesql.cpp" line="167"/>
         <source>Actual Errors</source>
         <translation>Actual Errors</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="76"/>
+        <location filename="../sql/chartablesql.cpp" line="168"/>
         <source>Frequency</source>
         <translation>Frequency</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="77"/>
+        <location filename="../sql/chartablesql.cpp" line="169"/>
         <source>Error Rate</source>
         <translation>Error Rate</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="80"/>
+        <location filename="../sql/chartablesql.cpp" line="172"/>
         <source>This column shows all of the
 characters typed</source>
         <translation>This column shows all of the
 characters typed</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="84"/>
+        <location filename="../sql/chartablesql.cpp" line="176"/>
         <source>The character was supposed to be typed, but wasn&apos;t</source>
         <translation>The character was supposed to be typed, but wasn&apos;t</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="87"/>
+        <location filename="../sql/chartablesql.cpp" line="179"/>
         <source>Character was mistyped</source>
         <translation>Character was mistyped</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="89"/>
+        <location filename="../sql/chartablesql.cpp" line="181"/>
         <source>This column indicates the total frequency of each
 character shown</source>
         <translation>This column indicates the total frequency of each
 character shown</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="93"/>
+        <location filename="../sql/chartablesql.cpp" line="185"/>
         <source>The error rate shows which characters give
 you the most problems. The error rate is
 calculated from the value &quot;Target Error&quot;
@@ -115,12 +115,12 @@ calculated from the value &quot;Target Error&quot;
 and the value &quot;Frequency&quot;.</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="117"/>
+        <location filename="../sql/chartablesql.cpp" line="90"/>
         <source>Reset characters</source>
         <translation>Reset characters</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="191"/>
+        <location filename="../sql/chartablesql.cpp" line="195"/>
         <source>Recorded error rates affect the intelligence feature and the selection of the text to be dictated. If the error rate for a certain character is excessively high it might be useful to reset the list.
 
 All recorded characters will now be deleted.
@@ -840,8 +840,8 @@ automatically after at least %1 characters.</translation>
     </message>
     <message>
         <location filename="../widget/lessondialog.cpp" line="117"/>
-        <source>&lt;u&gt;Explanation:&lt;/u&gt;&lt;br&gt;&amp;nbsp;&lt;br&gt;Every line (separated by Enter key) is equivalent to a unit of the lesson. There are two types of lesson dictation:&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Sentence Lesson&lt;/b&gt; - every line (sentence) will be dictated exactly how it was entered here with a line break at the end.&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Word Lesson&lt;/b&gt; - the lines will be separated by blanks and a line break passes auomatically after at least %1 characters.</source>
-        <translation>&lt;u&gt;Explanation:&lt;/u&gt;&lt;br&gt;&amp;nbsp;&lt;br&gt;Every line (separated by Enter key) is equivalent to a unit of the lesson. There are two types of lesson dictation:&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Sentence Lesson&lt;/b&gt; - every line (sentence) will be dictated exactly how it was entered here with a line break at the end.&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Word Lesson&lt;/b&gt; - the lines will be separated by blanks and a line break passes auomatically after at least %1 characters.</translation>
+        <source>&lt;u&gt;Explanation:&lt;/u&gt;&lt;br&gt;&amp;nbsp;&lt;br&gt;Every line (separated by Enter key) is equivalent to a unit of the lesson. There are two types of lesson dictation:&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Sentence Lesson&lt;/b&gt; - every line (sentence) will be dictated exactly how it was entered here with a line break at the end.&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Word Lesson&lt;/b&gt; - the lines will be separated by blanks and a line break passes automatically after at least %1 characters.</source>
+        <translation>&lt;u&gt;Explanation:&lt;/u&gt;&lt;br&gt;&amp;nbsp;&lt;br&gt;Every line (separated by Enter key) is equivalent to a unit of the lesson. There are two types of lesson dictation:&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Sentence Lesson&lt;/b&gt; - every line (sentence) will be dictated exactly how it was entered here with a line break at the end.&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Word Lesson&lt;/b&gt; - the lines will be separated by blanks and a line break passes automatically after at least %1 characters.</translation>
     </message>
     <message>
         <location filename="../widget/lessondialog.cpp" line="127"/>
@@ -1123,99 +1123,99 @@ automatically after at least %1 characters.</translation>
 <context>
     <name>LessonTableSql</name>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="126"/>
+        <location filename="../sql/lessontablesql.cpp" line="122"/>
         <source>Show: </source>
         <translation>Show: </translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="128"/>
+        <location filename="../sql/lessontablesql.cpp" line="124"/>
         <source>All Lessons</source>
         <translation>All Lessons</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="129"/>
+        <location filename="../sql/lessontablesql.cpp" line="125"/>
         <source>Training Lessons</source>
         <translation>Training Lessons</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="130"/>
+        <location filename="../sql/lessontablesql.cpp" line="126"/>
         <source>Open Lessons</source>
         <translation>Open Lessons</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="131"/>
+        <location filename="../sql/lessontablesql.cpp" line="127"/>
         <source>Own Lessons</source>
         <translation>Own Lessons</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="266"/>
+        <location filename="../sql/lessontablesql.cpp" line="255"/>
         <source>Lesson</source>
         <translation>Lesson</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="267"/>
+        <location filename="../sql/lessontablesql.cpp" line="256"/>
         <source>Time</source>
         <translation>Time</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="268"/>
+        <location filename="../sql/lessontablesql.cpp" line="257"/>
         <source>Duration</source>
         <translation>Duration</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="269"/>
+        <location filename="../sql/lessontablesql.cpp" line="258"/>
         <source>Characters</source>
         <translation>Characters</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="270"/>
+        <location filename="../sql/lessontablesql.cpp" line="259"/>
         <source>Errors</source>
         <translation>Errors</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="271"/>
+        <location filename="../sql/lessontablesql.cpp" line="260"/>
         <source>Rate</source>
         <translation>Rate</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="272"/>
+        <location filename="../sql/lessontablesql.cpp" line="261"/>
         <source>Cpm</source>
         <translation>Cpm</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="273"/>
+        <location filename="../sql/lessontablesql.cpp" line="262"/>
         <source>Score</source>
         <translation>Score</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="276"/>
+        <location filename="../sql/lessontablesql.cpp" line="265"/>
         <source>This column shows the names
 of completed lessons</source>
         <translation>This column shows the names
 of completed lessons</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="280"/>
+        <location filename="../sql/lessontablesql.cpp" line="269"/>
         <source>Start time of the lesson</source>
         <translation>Start time of the lesson</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="282"/>
+        <location filename="../sql/lessontablesql.cpp" line="271"/>
         <source>Total duration of the lesson</source>
         <translation>Total duration of the lesson</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="283"/>
+        <location filename="../sql/lessontablesql.cpp" line="272"/>
         <source>Number of characters dictated</source>
         <translation>Number of characters dictated</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="286"/>
+        <location filename="../sql/lessontablesql.cpp" line="275"/>
         <source>Number of typing errors</source>
         <translation>Number of typing errors</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="288"/>
+        <location filename="../sql/lessontablesql.cpp" line="277"/>
         <source>The error rate is calculated as follows:
 Errors / Characters
 The lower the error rate the better!</source>
@@ -1224,14 +1224,14 @@ Errors / Characters
 The lower the error rate the better!</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="293"/>
+        <location filename="../sql/lessontablesql.cpp" line="282"/>
         <source>&quot;Cpm&quot; indicates how many characters per minute
 were entered on average</source>
         <translation>&quot;Cpm&quot; indicates how many characters per minute
 were entered on average</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="297"/>
+        <location filename="../sql/lessontablesql.cpp" line="286"/>
         <source>The score is calculated as follows:
 ((Characters - (20 x Errors)) / Duration in minutes) x 0.4
 
