@@ -55,54 +55,54 @@
 <context>
     <name>CharTableSql</name>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="73"/>
+        <location filename="../sql/chartablesql.cpp" line="165"/>
         <source>Characters</source>
         <translation>Caractères</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="74"/>
+        <location filename="../sql/chartablesql.cpp" line="166"/>
         <source>Target Errors</source>
         <translation>Erreurs</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="75"/>
+        <location filename="../sql/chartablesql.cpp" line="167"/>
         <source>Actual Errors</source>
         <translation>Typo</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="76"/>
+        <location filename="../sql/chartablesql.cpp" line="168"/>
         <source>Frequency</source>
         <translation>Fréquence</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="77"/>
+        <location filename="../sql/chartablesql.cpp" line="169"/>
         <source>Error Rate</source>
         <translation>Taux d&apos;erreur</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="80"/>
+        <location filename="../sql/chartablesql.cpp" line="172"/>
         <source>This column shows all of the
 characters typed</source>
         <translation>Cette colonne affiche tous les caractères tapés</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="84"/>
+        <location filename="../sql/chartablesql.cpp" line="176"/>
         <source>The character was supposed to be typed, but wasn&apos;t</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="87"/>
+        <location filename="../sql/chartablesql.cpp" line="179"/>
         <source>Character was mistyped</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="89"/>
+        <location filename="../sql/chartablesql.cpp" line="181"/>
         <source>This column indicates the total frequency of each
 character shown</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="93"/>
+        <location filename="../sql/chartablesql.cpp" line="185"/>
         <source>The error rate shows which characters give
 you the most problems. The error rate is
 calculated from the value &quot;Target Error&quot;
@@ -113,12 +113,12 @@ C&apos;est le rapport entre le nombre d&apos;erreurs et
 la fréquence d&apos;apparition du caractère dans la dictée.</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="117"/>
+        <location filename="../sql/chartablesql.cpp" line="90"/>
         <source>Reset characters</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="191"/>
+        <location filename="../sql/chartablesql.cpp" line="195"/>
         <source>Recorded error rates affect the intelligence feature and the selection of the text to be dictated. If the error rate for a certain character is excessively high it might be useful to reset the list.
 
 All recorded characters will now be deleted.
@@ -728,7 +728,7 @@ La mise à jour a échoué.</translation>
     </message>
     <message>
         <location filename="../widget/lessondialog.cpp" line="117"/>
-        <source>&lt;u&gt;Explanation:&lt;/u&gt;&lt;br&gt;&amp;nbsp;&lt;br&gt;Every line (separated by Enter key) is equivalent to a unit of the lesson. There are two types of lesson dictation:&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Sentence Lesson&lt;/b&gt; - every line (sentence) will be dictated exactly how it was entered here with a line break at the end.&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Word Lesson&lt;/b&gt; - the lines will be separated by blanks and a line break passes auomatically after at least %1 characters.</source>
+        <source>&lt;u&gt;Explanation:&lt;/u&gt;&lt;br&gt;&amp;nbsp;&lt;br&gt;Every line (separated by Enter key) is equivalent to a unit of the lesson. There are two types of lesson dictation:&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Sentence Lesson&lt;/b&gt; - every line (sentence) will be dictated exactly how it was entered here with a line break at the end.&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Word Lesson&lt;/b&gt; - the lines will be separated by blanks and a line break passes automatically after at least %1 characters.</source>
         <translation>&lt;u&gt;Explication :&lt;/u&gt;&lt;br&gt;&amp;nbsp;&lt;br&gt;Chaque ligne est équivalente à une unité de leçon. Il y a deux façons de dicter une leçon :&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Leçon de phrases&lt;/b&gt; - chaque ligne (phrase) sera dictée jusqu&apos;à la fin.&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Leçon de mots&lt;/b&gt; - Les mots seront dictés les uns à la suite des autres mais contrairement au précédent mode, le retour à la ligne se fera après %1 caractères.</translation>
     </message>
     <message>
@@ -765,7 +765,7 @@ by blanks. A line break passes
 automatically after at least %1 characters.</source>
         <translation>Every unit (line) will be seperated 
 by blanks. A line break passes 
-auomatically after at least %1 caractères.</translation>
+automatically after at least %1 caractères.</translation>
     </message>
     <message>
         <location filename="../widget/lessondialog.cpp" line="160"/>
@@ -1070,112 +1070,112 @@ auomatically after at least %1 caractères.</translation>
 <context>
     <name>LessonTableSql</name>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="126"/>
+        <location filename="../sql/lessontablesql.cpp" line="122"/>
         <source>Show: </source>
         <translation>Afficher : </translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="128"/>
+        <location filename="../sql/lessontablesql.cpp" line="124"/>
         <source>All Lessons</source>
         <translation>Toutes les leçons</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="129"/>
+        <location filename="../sql/lessontablesql.cpp" line="125"/>
         <source>Training Lessons</source>
         <translation>Leçons d&apos;entraînement</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="130"/>
+        <location filename="../sql/lessontablesql.cpp" line="126"/>
         <source>Open Lessons</source>
         <translation>Leçons ouvertes</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="131"/>
+        <location filename="../sql/lessontablesql.cpp" line="127"/>
         <source>Own Lessons</source>
         <translation>Leçons personnelles</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="266"/>
+        <location filename="../sql/lessontablesql.cpp" line="255"/>
         <source>Lesson</source>
         <translation>Leçon</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="267"/>
+        <location filename="../sql/lessontablesql.cpp" line="256"/>
         <source>Time</source>
         <translation>Date</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="268"/>
+        <location filename="../sql/lessontablesql.cpp" line="257"/>
         <source>Duration</source>
         <translation>Durée</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="269"/>
+        <location filename="../sql/lessontablesql.cpp" line="258"/>
         <source>Characters</source>
         <translation>Caractères</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="270"/>
+        <location filename="../sql/lessontablesql.cpp" line="259"/>
         <source>Errors</source>
         <translation>Erreurs</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="271"/>
+        <location filename="../sql/lessontablesql.cpp" line="260"/>
         <source>Rate</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="272"/>
+        <location filename="../sql/lessontablesql.cpp" line="261"/>
         <source>Cpm</source>
         <translation>CPM</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="273"/>
+        <location filename="../sql/lessontablesql.cpp" line="262"/>
         <source>Score</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="276"/>
+        <location filename="../sql/lessontablesql.cpp" line="265"/>
         <source>This column shows the names
 of completed lessons</source>
         <translation>Cette colonne affiche le nom
 des leçons complétées</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="280"/>
+        <location filename="../sql/lessontablesql.cpp" line="269"/>
         <source>Start time of the lesson</source>
         <translation>Début de la leçon</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="282"/>
+        <location filename="../sql/lessontablesql.cpp" line="271"/>
         <source>Total duration of the lesson</source>
         <translation>Durée totale de la leçon</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="283"/>
+        <location filename="../sql/lessontablesql.cpp" line="272"/>
         <source>Number of characters dictated</source>
         <translation>Nombre de caractères dictés</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="286"/>
+        <location filename="../sql/lessontablesql.cpp" line="275"/>
         <source>Number of typing errors</source>
         <translation>Nombre d&apos;erreurs de frappe</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="288"/>
+        <location filename="../sql/lessontablesql.cpp" line="277"/>
         <source>The error rate is calculated as follows:
 Errors / Characters
 The lower the error rate the better!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="293"/>
+        <location filename="../sql/lessontablesql.cpp" line="282"/>
         <source>&quot;Cpm&quot; indicates how many characters per minute
 were entered on average</source>
         <translation>&quot;CPM&quot; indique le nombre moyen de caractères tapés par minute</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="297"/>
+        <location filename="../sql/lessontablesql.cpp" line="286"/>
         <source>The score is calculated as follows:
 ((Characters - (20 x Errors)) / Duration in minutes) x 0.4
 
