@@ -55,55 +55,55 @@
 <context>
     <name>CharTableSql</name>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="73"/>
+        <location filename="../sql/chartablesql.cpp" line="165"/>
         <source>Characters</source>
         <translation>Tekens</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="74"/>
+        <location filename="../sql/chartablesql.cpp" line="166"/>
         <source>Target Errors</source>
         <translation>Doelfouten</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="75"/>
+        <location filename="../sql/chartablesql.cpp" line="167"/>
         <source>Actual Errors</source>
         <translation>Werkelijke fouten</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="76"/>
+        <location filename="../sql/chartablesql.cpp" line="168"/>
         <source>Frequency</source>
         <translation>Frequentie</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="77"/>
+        <location filename="../sql/chartablesql.cpp" line="169"/>
         <source>Error Rate</source>
         <translation>Foutpercentage</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="80"/>
+        <location filename="../sql/chartablesql.cpp" line="172"/>
         <source>This column shows all of the
 characters typed</source>
         <translation>Deze kolom toont alle
 getypte tekens</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="84"/>
+        <location filename="../sql/chartablesql.cpp" line="176"/>
         <source>The character was supposed to be typed, but wasn&apos;t</source>
         <translation>Het karakter had moeten worden getypt, maar was niet</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="87"/>
+        <location filename="../sql/chartablesql.cpp" line="179"/>
         <source>Character was mistyped</source>
         <translation>Karakter is verkeerd getypt</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="89"/>
+        <location filename="../sql/chartablesql.cpp" line="181"/>
         <source>This column indicates the total frequency of each
 character shown</source>
         <translation>Deze kolom geeft de totale frequentie aan van elk getoond teken</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="93"/>
+        <location filename="../sql/chartablesql.cpp" line="185"/>
         <source>The error rate shows which characters give
 you the most problems. The error rate is
 calculated from the value &quot;Target Error&quot;
@@ -114,12 +114,12 @@ berekend uit de waarde &quot;Doelfout&quot;
 en de waarde &quot;Frequentie&quot;.</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="117"/>
+        <location filename="../sql/chartablesql.cpp" line="90"/>
         <source>Reset characters</source>
         <translation>Tekens resetten</translation>
     </message>
     <message>
-        <location filename="../sql/chartablesql.cpp" line="191"/>
+        <location filename="../sql/chartablesql.cpp" line="195"/>
         <source>Recorded error rates affect the intelligence feature and the selection of the text to be dictated. If the error rate for a certain character is excessively high it might be useful to reset the list.
 
 All recorded characters will now be deleted.
@@ -738,7 +738,7 @@ Update mislukt.</translation>
     </message>
     <message>
         <location filename="../widget/lessondialog.cpp" line="117"/>
-        <source>&lt;u&gt;Explanation:&lt;/u&gt;&lt;br&gt;&amp;nbsp;&lt;br&gt;Every line (separated by Enter key) is equivalent to a unit of the lesson. There are two types of lesson dictation:&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Sentence Lesson&lt;/b&gt; - every line (sentence) will be dictated exactly how it was entered here with a line break at the end.&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Word Lesson&lt;/b&gt; - the lines will be separated by blanks and a line break passes auomatically after at least %1 characters.</source>
+        <source>&lt;u&gt;Explanation:&lt;/u&gt;&lt;br&gt;&amp;nbsp;&lt;br&gt;Every line (separated by Enter key) is equivalent to a unit of the lesson. There are two types of lesson dictation:&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Sentence Lesson&lt;/b&gt; - every line (sentence) will be dictated exactly how it was entered here with a line break at the end.&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Word Lesson&lt;/b&gt; - the lines will be separated by blanks and a line break passes automatically after at least %1 characters.</source>
         <translation>&lt;u&gt;Uitleg:&lt;/u&gt;&lt;br&gt;&amp;nbsp;&lt;br&gt;Elke regel (gescheiden door Enter-toets) komt overeen met een onderdeel van de les. Er zijn twee soorten lesdictaten:&lt;br&gt; &amp;nbsp;&lt;br&gt;&lt;b&gt;Zinles&lt;/b&gt; - elke regel (zin) wordt precies gedicteerd zoals deze hier is ingevoerd met een regeleinde aan het einde.&lt;br&gt;&amp;nbsp;&lt;br&gt;&lt;b&gt;Woordles &lt;/b&gt; - de regels worden gescheiden door spaties en een regeleinde gaat automatisch voorbij na minstens %1 karakters.</translation>
     </message>
     <message>
@@ -1080,99 +1080,99 @@ automatisch na ten minste %1 tekens.</translation>
 <context>
     <name>LessonTableSql</name>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="126"/>
+        <location filename="../sql/lessontablesql.cpp" line="122"/>
         <source>Show: </source>
         <translation>Tonen: </translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="128"/>
+        <location filename="../sql/lessontablesql.cpp" line="124"/>
         <source>All Lessons</source>
         <translation>Alle lessen</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="129"/>
+        <location filename="../sql/lessontablesql.cpp" line="125"/>
         <source>Training Lessons</source>
         <translation>Trainingslessen</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="130"/>
+        <location filename="../sql/lessontablesql.cpp" line="126"/>
         <source>Open Lessons</source>
         <translation>Open lessen</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="131"/>
+        <location filename="../sql/lessontablesql.cpp" line="127"/>
         <source>Own Lessons</source>
         <translation>Eigen lessen</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="266"/>
+        <location filename="../sql/lessontablesql.cpp" line="255"/>
         <source>Lesson</source>
         <translation>Les</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="267"/>
+        <location filename="../sql/lessontablesql.cpp" line="256"/>
         <source>Time</source>
         <translation>Tijd</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="268"/>
+        <location filename="../sql/lessontablesql.cpp" line="257"/>
         <source>Duration</source>
         <translation>Duur</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="269"/>
+        <location filename="../sql/lessontablesql.cpp" line="258"/>
         <source>Characters</source>
         <translation>Tekens</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="270"/>
+        <location filename="../sql/lessontablesql.cpp" line="259"/>
         <source>Errors</source>
         <translation>Fouten</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="271"/>
+        <location filename="../sql/lessontablesql.cpp" line="260"/>
         <source>Rate</source>
         <translation>Tarief</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="272"/>
+        <location filename="../sql/lessontablesql.cpp" line="261"/>
         <source>Cpm</source>
         <translation>Tpm</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="273"/>
+        <location filename="../sql/lessontablesql.cpp" line="262"/>
         <source>Score</source>
         <translation>Score</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="276"/>
+        <location filename="../sql/lessontablesql.cpp" line="265"/>
         <source>This column shows the names
 of completed lessons</source>
         <translation>Deze kolom toont de namen
 van afgeronde lessen</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="280"/>
+        <location filename="../sql/lessontablesql.cpp" line="269"/>
         <source>Start time of the lesson</source>
         <translation>Starttijd van de les</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="282"/>
+        <location filename="../sql/lessontablesql.cpp" line="271"/>
         <source>Total duration of the lesson</source>
         <translation>Totale duur van de les</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="283"/>
+        <location filename="../sql/lessontablesql.cpp" line="272"/>
         <source>Number of characters dictated</source>
         <translation>Aantal gedicteerde tekens</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="286"/>
+        <location filename="../sql/lessontablesql.cpp" line="275"/>
         <source>Number of typing errors</source>
         <translation>Aantal typefouten</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="288"/>
+        <location filename="../sql/lessontablesql.cpp" line="277"/>
         <source>The error rate is calculated as follows:
 Errors / Characters
 The lower the error rate the better!</source>
@@ -1181,14 +1181,14 @@ Fouten / tekens
 Hoe lager het foutenpercentage, hoe beter!</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="293"/>
+        <location filename="../sql/lessontablesql.cpp" line="282"/>
         <source>&quot;Cpm&quot; indicates how many characters per minute
 were entered on average</source>
         <translation>&quot;Tpm&quot; geeft aan hoeveel tekens er gemiddeld per minuut
  werden ingevoerd</translation>
     </message>
     <message>
-        <location filename="../sql/lessontablesql.cpp" line="297"/>
+        <location filename="../sql/lessontablesql.cpp" line="286"/>
         <source>The score is calculated as follows:
 ((Characters - (20 x Errors)) / Duration in minutes) x 0.4
 
