@@ -26,7 +26,7 @@ EvaluationWidget::EvaluationWidget(int row, int type, QList<QChar> charList,
     , currentRow(row)
 {
     // Object of the user's lesson table
-    lessonTableSql = new LessonTableSql(row, type, charList, mistakeList, this);
+    lessonTableSql = new LessonTableSql(row, type, this);
 
     // Object of the comparison chart widget
     QWidget* comparisonContainer = new QWidget();
