@@ -35,7 +35,6 @@ SPDX-License-Identifier: GPL-2.0-only
 
 StartWidget::StartWidget(QWidget* parent)
     : QWidget(parent)
-    , companyLogo(new CompanyLogo(this))
 {
     readLicenseSettings();
 
@@ -406,23 +405,12 @@ void StartWidget::createButtons()
 
 void StartWidget::createLayout()
 {
-    // Button layout horizontal
-    QHBoxLayout* buttonLayoutHorizontal = new QHBoxLayout;
-    buttonLayoutHorizontal->addWidget(buttonHelp);
-    buttonLayoutHorizontal->addWidget(buttonTraining);
-    // Button layout vertical
-    QVBoxLayout* buttonLayoutVertical = new QVBoxLayout;
-    buttonLayoutVertical->addSpacing(20);
-    buttonLayoutVertical->addLayout(buttonLayoutHorizontal);
-    // Logo layout vertical
-    QVBoxLayout* logoLayout = new QVBoxLayout;
-    logoLayout->addSpacing(10);
-    logoLayout->addWidget(companyLogo);
-    // Logo layout + button layout horizontal
+    // Bottom layout
     QHBoxLayout* bottomLayout = new QHBoxLayout;
-    bottomLayout->addLayout(logoLayout);
     bottomLayout->addStretch(1);
-    bottomLayout->addLayout(buttonLayoutVertical);
+    bottomLayout->addWidget(buttonHelp);
+    bottomLayout->addWidget(buttonTraining);
+
     // Group error handling and other user support vertical
     /*QVBoxLayout *bottomboxesLayoutV = new QVBoxLayout;
 bottomboxesLayoutV->addWidget(groupError);
@@ -442,7 +430,7 @@ bottomboxesLayoutV->addWidget(groupIntelligence);*/
     // Full layout of all widgets vertical
     QVBoxLayout* mainLayout = new QVBoxLayout;
     mainLayout->addLayout(centerLayout);
-    mainLayout->addSpacing(1);
+    mainLayout->addSpacing(20);
     mainLayout->addLayout(bottomLayout);
     mainLayout->setSpacing(15);
     // Pass layout to parent widget (this)
