@@ -44,13 +44,12 @@ TrainingWidget::TrainingWidget(
     , oneErrorFlag(false)
     , timer(new QTimer(this))
     , metronomeTimer(new QTimer(this))
-    , companyLogo(new CompanyLogo(this, true))
 {
     // Init sound file
     bells.setSource(
-        QUrl::fromLocalFile(t10::tipp10_datadir + QString("error.wav")));
+        QUrl::fromLocalFile(t10::getDataDir() + QString("error.wav")));
     metronomeSound.setSource(
-        QUrl::fromLocalFile(t10::tipp10_datadir + QString("metronome.wav")));
+        QUrl::fromLocalFile(t10::getDataDir() + QString("metronome.wav")));
 
     // Create all type trainer objects
     // 1. Keyboard (set focus!)
@@ -84,7 +83,6 @@ TrainingWidget::TrainingWidget(
             keyBoard->setVisible(false);
         }
         // statusBar->setVisible(false);
-        // companyLogo->setVisible(false);
         parent->setMinimumSize(t10::app_width_small, t10::app_height_small);
         if (!parent->isMaximized()) {
             parent->resize(t10::app_width_small, t10::app_height_small);
@@ -117,25 +115,13 @@ void TrainingWidget::createButtons()
 
 void TrainingWidget::createLayout()
 {
-    // Button layout horizontal
-    QHBoxLayout* buttonLayoutHorizontal = new QHBoxLayout;
-    buttonLayoutHorizontal->addWidget(buttonCancel);
-    buttonLayoutHorizontal->addSpacing(10);
-    buttonLayoutHorizontal->addWidget(buttonHelp);
-    buttonLayoutHorizontal->addWidget(buttonPause);
-    // Button layout vertical
-    QVBoxLayout* buttonLayoutVertical = new QVBoxLayout;
-    buttonLayoutVertical->addSpacing(11);
-    buttonLayoutVertical->addLayout(buttonLayoutHorizontal);
-    // Logo layout vertical
-    QVBoxLayout* logoLayout = new QVBoxLayout;
-    logoLayout->addSpacing(1);
-    logoLayout->addWidget(companyLogo);
-    // Logo layout + button layout horizontal
+    // Bottom layout
     QHBoxLayout* bottomLayout = new QHBoxLayout;
-    bottomLayout->addLayout(logoLayout);
     bottomLayout->addStretch(1);
-    bottomLayout->addLayout(buttonLayoutVertical);
+    bottomLayout->addWidget(buttonCancel);
+    bottomLayout->addSpacing(10);
+    bottomLayout->addWidget(buttonHelp);
+    bottomLayout->addWidget(buttonPause);
     // Ticker layout horizontal
     QHBoxLayout* tickerboardLayout = new QHBoxLayout;
     tickerboardLayout->addStretch(1);
